==> open-xchange-realtime-core_7.6.0.orig.tar.bz2: open-xchange-realtime-core-7.6.0/com.openexchange.realtime.presence.subscribe/src/com/openexchange/realtime/presence/subscribe/osgi/PresenceSubscribeActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.presence.subscribe.osgi;

import java.util.Arrays;
import java.util.Collection;
import com.openexchange.config.ConfigurationService;
import com.openexchange.context.ContextService;
import com.openexchange.database.CreateTableService;
import com.openexchange.database.DatabaseService;
import com.openexchange.groupware.update.UpdateTask;
import com.openexchange.groupware.update.UpdateTaskProviderService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.realtime.directory.ResourceDirectory;
import com.openexchange.realtime.dispatch.MessageDispatcher;
import com.openexchange.realtime.presence.subscribe.PresenceSubscriptionService;
import com.openexchange.realtime.presence.subscribe.database.AddPrimaryKeyTask;
import com.openexchange.realtime.presence.subscribe.database.AddUUIDColumnTask;
import com.openexchange.realtime.presence.subscribe.database.CreatePresenceSubscriptionDB;
import com.openexchange.realtime.presence.subscribe.database.PresenceSubscriptionsTable;
import com.openexchange.realtime.presence.subscribe.impl.SubscriptionServiceImpl;
import com.openexchange.user.UserService;

/**
 * {@link PresenceSubscribeActivator}
 *
 * @author <a href="mailto:martin.herfurth@open-xchange.com">Martin Herfurth</a>
 */
public class PresenceSubscribeActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] {
            ResourceDirectory.class, DatabaseService.class, ContextService.class, UserService.class, MessageDispatcher.class,
            ConfigurationService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        final DatabaseService dbService = getService(DatabaseService.class);
        // SubscriptionsSQL.db = dbService;
        registerService(PresenceSubscriptionService.class, new SubscriptionServiceImpl(this));
        registerService(CreateTableService.class, new PresenceSubscriptionsTable());

        registerService(UpdateTaskProviderService.class, new UpdateTaskProviderService() {

            @Override
            public Collection<? extends UpdateTask> getUpdateTasks() {
                return Arrays.asList(
                    new CreatePresenceSubscriptionDB(dbService),
                    new AddUUIDColumnTask(dbService),
                    new AddPrimaryKeyTask(dbService));
            }
        });
    }
}

==> open-xchange-realtime-core_7.6.2.orig.tar.bz2: open-xchange-realtime-core-7.6.2/com.openexchange.realtime.presence.subscribe/src/com/openexchange/realtime/presence/subscribe/osgi/PresenceSubscribeActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.presence.subscribe.osgi;

import java.util.Arrays;
import java.util.Collection;
import com.openexchange.config.ConfigurationService;
import com.openexchange.context.ContextService;
import com.openexchange.database.CreateTableService;
import com.openexchange.database.DatabaseService;
import com.openexchange.groupware.update.UpdateTask;
import com.openexchange.groupware.update.UpdateTaskProviderService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.realtime.directory.ResourceDirectory;
import com.openexchange.realtime.dispatch.MessageDispatcher;
import com.openexchange.realtime.presence.subscribe.PresenceSubscriptionService;
import com.openexchange.realtime.presence.subscribe.database.AddPrimaryKeyTask;
import com.openexchange.realtime.presence.subscribe.database.AddPrimaryKeyTaskV2;
import com.openexchange.realtime.presence.subscribe.database.AddUUIDColumnTask;
import com.openexchange.realtime.presence.subscribe.database.CreatePresenceSubscriptionDB;
import com.openexchange.realtime.presence.subscribe.database.PresenceSubscriptionsTable;
import com.openexchange.realtime.presence.subscribe.impl.SubscriptionServiceImpl;
import com.openexchange.user.UserService;

/**
 * {@link PresenceSubscribeActivator}
 *
 * @author <a href="mailto:martin.herfurth@open-xchange.com">Martin Herfurth</a>
 */
public class PresenceSubscribeActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] {
            ResourceDirectory.class, DatabaseService.class, ContextService.class, UserService.class, MessageDispatcher.class,
            ConfigurationService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        final DatabaseService dbService = getService(DatabaseService.class);
        // SubscriptionsSQL.db = dbService;
        registerService(PresenceSubscriptionService.class, new SubscriptionServiceImpl(this));
        registerService(CreateTableService.class, new PresenceSubscriptionsTable());

        registerService(UpdateTaskProviderService.class, new UpdateTaskProviderService() {

            @Override
            public Collection<? extends UpdateTask> getUpdateTasks() {
                return Arrays.asList(
                    new CreatePresenceSubscriptionDB(dbService),
                    new AddUUIDColumnTask(dbService),
                    new AddPrimaryKeyTask(dbService),
                    new AddPrimaryKeyTaskV2(dbService));
            }
        });
    }
}
